@@ -1,5 +1,5 @@
 /*
- * $Id: cap_text.c,v 1.4 1998/05/24 22:54:09 morgan Exp $
+ * $Id: cap_text.c,v 1.3 1999/11/18 06:03:26 morgan Exp $
  *
  * Copyright (c) 1997-8 Andrew G Morgan <morgan@linux.kernel.org>
  * Copyright (c) 1997 Andrew Main <zefram@dcs.warwick.ac.uk>
@@ -16,8 +16,6 @@
 #include <ctype.h>
 #include <stdio.h>
 
-char *strdup(const char *s);
-
 /* Maximum output text length (16 per cap) */
 #define CAP_TEXT_SIZE    (16*__CAP_BITS)
 
@@ -246,7 +244,7 @@ char *cap_to_text(cap_t caps, ssize_t *length_p)
     int m, n, t;
 
     /* Check arguments */
-    if (!good_cap_t(caps) || length_p == NULL) {
+    if (!good_cap_t(caps)) {
 	errno = EINVAL;
 	return NULL;
     }
@@ -302,12 +300,24 @@ char *cap_to_text(cap_t caps, ssize_t *length_p)
 	}
 
     _cap_debug("%s", buf);
-    *length_p = p - buf;
-    return (strdup(buf));
+    if (length_p) {
+	*length_p = p - buf;
+    }
+
+    return (_libcap_strdup(buf));
 }
 
 /*
  * $Log: cap_text.c,v $
+ * Revision 1.3  1999/11/18 06:03:26  morgan
+ * fixed cap_free to work as indicated in manuals
+ *
+ * Revision 1.2  1999/04/17 23:25:09  morgan
+ * fixes from peeterj
+ *
+ * Revision 1.1.1.1  1999/04/17 22:16:31  morgan
+ * release 1.0 of libcap
+ *
  * Revision 1.4  1998/05/24 22:54:09  morgan
  * updated for 2.1.104
  *
