@@ -1,5 +1,5 @@
 /*
- * $Id: getpcaps.c,v 1.4 1998/09/20 23:07:08 morgan Exp $
+ * $Id: getpcaps.c,v 1.2 1999/11/18 06:04:25 morgan Exp $
  *
  * Copyright (c) 1997 Andrew G. Morgan  <morgan@linux.kernel.org>
  *
@@ -53,7 +53,7 @@ int main(int argc, char **argv)
 	} else {
 	    char *result = cap_to_text(cap_d, &length);
 	    fprintf(stderr, "Capabilities for `%s': %s\n", *argv, result);
-	    free(result);
+	    cap_free(result);
 	    result = NULL;
 	}
     }
@@ -63,6 +63,12 @@ int main(int argc, char **argv)
 
 /*
  * $Log: getpcaps.c,v $
+ * Revision 1.2  1999/11/18 06:04:25  morgan
+ * use cap_free and not free for string from cap_to_text()
+ *
+ * Revision 1.1.1.1  1999/04/17 22:16:31  morgan
+ * release 1.0 of libcap
+ *
  * Revision 1.4  1998/09/20 23:07:08  morgan
  * fixed comment at top
  *
