@@ -1,9 +1,9 @@
 /*
- * $Id: setpcaps.c,v 1.2 1998/06/08 00:17:38 morgan Exp $
+ * $Id: setpcaps.c,v 1.2 1999/11/18 06:04:26 morgan Exp $
  *
  * Copyright (c) 1997-8 Andrew G. Morgan  <morgan@linux.kernel.org>
  *
- * This sets the capabilities of a given file.
+ * This sets the capabilities of a given process.
  */
 
 #include <sys/types.h>
@@ -101,7 +101,7 @@ int main(int argc, char **argv)
 
 	    result = cap_to_text(cap_d, &length);
 	    fprintf(stderr, "[caps set to:\n%s\n]\n", result);
-	    free(result);
+	    cap_free(result);
 	    result = NULL;
 	}
 #endif
@@ -127,6 +127,15 @@ int main(int argc, char **argv)
 
 /*
  * $Log: setpcaps.c,v $
+ * Revision 1.2  1999/11/18 06:04:26  morgan
+ * use cap_free and not free for string from cap_to_text()
+ *
+ * Revision 1.1.1.1  1999/04/17 22:16:31  morgan
+ * release 1.0 of libcap
+ *
+ * Revision 1.3  1998/09/20 23:07:08  morgan
+ * fixed comment at top
+ *
  * Revision 1.2  1998/06/08 00:17:38  morgan
  * change to accommodate alpha (glibc?)
  *
